==> unico_device_setuper-0.5.0-py3-none-any.whl: unico_device_setuper/lib/unitech/impl/models/put_round_round_slots_id_round_body.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PutRoundRoundSlotsIdRoundBody")


@_attrs_define
class PutRoundRoundSlotsIdRoundBody:
    """
    Attributes:
        round_slots (Union[Unset, Any]):  Example: any.
        deactivation_date (Union[Unset, Any]):  Example: any.
    """

    round_slots: Union[Unset, Any] = UNSET
    deactivation_date: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        round_slots = self.round_slots

        deactivation_date = self.deactivation_date

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if round_slots is not UNSET:
            field_dict["roundSlots"] = round_slots
        if deactivation_date is not UNSET:
            field_dict["deactivationDate"] = deactivation_date

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        round_slots = d.pop("roundSlots", UNSET)

        deactivation_date = d.pop("deactivationDate", UNSET)

        put_round_round_slots_id_round_body = cls(
            round_slots=round_slots,
            deactivation_date=deactivation_date,
        )

        put_round_round_slots_id_round_body.additional_properties = d
        return put_round_round_slots_id_round_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> unico_device_setuper-1.10.0-py3-none-any.whl: unico_device_setuper/lib/unitech/impl/models/put_round_round_slots_id_round_body.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="PutRoundRoundSlotsIdRoundBody")


@_attrs_define
class PutRoundRoundSlotsIdRoundBody:
    """
    Attributes:
        id_round (Union[Unset, Any]):  Example: any.
    """

    id_round: Union[Unset, Any] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        id_round = self.id_round

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if id_round is not UNSET:
            field_dict["idRound"] = id_round

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id_round = d.pop("idRound", UNSET)

        put_round_round_slots_id_round_body = cls(
            id_round=id_round,
        )

        put_round_round_slots_id_round_body.additional_properties = d
        return put_round_round_slots_id_round_body

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
